==> node-v14.15.4.tar.gz: node-v14.15.4/test/parallel/test-http-client-parse-error.js <==
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

'use strict';
const common = require('../common');
const http = require('http');
const net = require('net');
const Countdown = require('../common/countdown');

const countdown = new Countdown(2, () => server.close());

const payloads = [
  'HTTP/1.1 302 Object Moved\r\nContent-Length: 0\r\n\r\nhi world',
  'bad http = should trigger parse error'
];

// Create a TCP server
const server =
  net.createServer(common.mustCall((c) => c.end(payloads.shift()), 2));

server.listen(0, common.mustCall(() => {
  for (let i = 0; i < 2; i++) {
    http.get({
      port: server.address().port,
      path: '/'
    }).on('error', common.mustCall((e) => {
      common.expectsError({
        code: 'HPE_INVALID_CONSTANT',
        message: 'Parse Error: Expected HTTP/'
      })(e);
      countdown.dec();
    }));
  }
}));

==> node-v14.19.0-rc.0.tar.gz: node-v14.19.0-rc.0/test/parallel/test-http-client-parse-error.js <==
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

'use strict';
const common = require('../common');
const http = require('http');
const net = require('net');
const Countdown = require('../common/countdown');

const countdown = new Countdown(2, () => server.close());

const payloads = [
  'HTTP/1.1 302 Object Moved\r\nContent-Length: 0\r\n\r\nhi world',
  'bad http = should trigger parse error',
];

// Create a TCP server
const server =
  net.createServer(common.mustCall((c) => c.end(payloads.shift()), 2));

server.listen(0, common.mustCall(() => {
  for (let i = 0; i < 2; i++) {
    http.get({
      port: server.address().port,
      path: '/'
    }).on('error', common.mustCall((e) => {
      common.expectsError({
        code: 'HPE_INVALID_CONSTANT',
        message: 'Parse Error: Expected HTTP/'
      })(e);
      countdown.dec();
    }));
  }
}));
